cgexplore.terms.Nonbonded
=========================

.. currentmodule:: cgexplore.terms

.. autoclass:: Nonbonded
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Nonbonded.atom_id
      ~Nonbonded.bead_class
      ~Nonbonded.bead_element
      ~Nonbonded.sigma
      ~Nonbonded.epsilon
      ~Nonbonded.force
   
   